@@ -18,6 +18,7 @@
 heatmap_vici <- function(res_2plot, inter=TRUE, baseline=NULL){
   
   if(inter){
+
     p <- ggplot(data = res_2plot) +
       geom_tile(aes_string(x="Stimulation", y="response", fill="pvalue"), color="white") +
       theme_minimal() +
@@ -26,11 +27,11 @@ heatmap_vici <- function(res_2plot, inter=TRUE, baseline=NULL){
               subtitle = "taking into account background response levels") +
       labs(caption = "made with VICI") +
       ylab("ICS response") +
-      scale_fill_manual(values = c("red4", "red2", "coral2", "grey70", "grey75", "grey80", "grey85","grey90", "grey95"),
-                        breaks = c("[0,0.001)", "[0.001,0.01)", "[0.01,0.05)", "[0.05,0.1)", "[0.1,0.2)", "[0.2,0.3)", "[0.3,0.4)", "[0.4,0.5)", "[0.5,1)"),
-                        labels = c("[0,0.001[", "[0.001,0.01[", "[0.01,0.05[", "[0.05,0.1[", "[0.1,0.2[", "[0.2,0.3[", "[0.3,0.4[", "[0.4,0.5[", "[0.5,1]"),
+      scale_fill_manual(values = c("red4", "red3", "coral2", "grey80", "grey90", "grey95"),
+                        breaks = c("[0,0.001)", "[0.001,0.01)", "[0.01,0.05)", "[0.05,0.1)", "[0.1,0.5)", "[0.5,1)"),
+                        labels = c("[0,0.001[", "[0.001,0.01[", "[0.01,0.05[", "[0.05,0.1[", "[0.1,0.5[", "[0.5,1]"),
                         name="P-value",
-                        limits = c("[0,0.001)", "[0.001,0.01)", "[0.01,0.05)", "[0.05,0.1)", "[0.1,0.2)", "[0.2,0.3)", "[0.3,0.4)", "[0.4,0.5)", "[0.5,1)")
+                        limits = c("[0,0.001)", "[0.001,0.01)", "[0.01,0.05)", "[0.05,0.1)", "[0.1,0.5)", "[0.5,1)")
       ) + facet_wrap(c("Arm"), labeller = "label_both")
   }else{
     p <- ggplot(data = res_2plot) +
@@ -41,13 +42,13 @@ heatmap_vici <- function(res_2plot, inter=TRUE, baseline=NULL){
               subtitle = "taking into account background response levels") +
       labs(caption = "made with VICI") +
       ylab("ICS response") +
-      scale_fill_manual(values = c("red4", "red2", "coral2", "grey70", "grey75", "grey80", "grey85","grey90", "grey95"),
-                        breaks = c("[0,0.001)", "[0.001,0.01)", "[0.01,0.05)", "[0.05,0.1)", "[0.1,0.2)", "[0.2,0.3)", "[0.3,0.4)", "[0.4,0.5)", "[0.5,1)"),
-                        labels = c("[0,0.001[", "[0.001,0.01[", "[0.01,0.05[", "[0.05,0.1[", "[0.1,0.2[", "[0.2,0.3[", "[0.3,0.4[", "[0.4,0.5[", "[0.5,1]"),
+      scale_fill_manual(values = c("red4", "red3", "coral2", "grey80", "grey90", "grey95"),
+                        breaks = c("[0,0.001)", "[0.001,0.01)", "[0.01,0.05)", "[0.05,0.1)", "[0.1,0.5)", "[0.5,1)"),
+                        labels = c("[0,0.001[", "[0.001,0.01[", "[0.01,0.05[", "[0.05,0.1[", "[0.1,0.5[", "[0.5,1]"),
                         name="P-value",
-                        limits = c("[0,0.001)", "[0.001,0.01)", "[0.01,0.05)", "[0.05,0.1)", "[0.1,0.2)", "[0.2,0.3)", "[0.3,0.4)", "[0.4,0.5)", "[0.5,1)")
+                        limits = c("[0,0.001)", "[0.001,0.01)", "[0.01,0.05)", "[0.05,0.1)", "[0.1,0.5)", "[0.5,1)")
       ) + facet_wrap(c("Timepoint"), labeller = "label_both")
   }
-
+  
   return(p)
 }
